# Bamboo Rules - JSON Rules fed to Pandas

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![License: MIT](https://img.shields.io/github/license/tnesztler/bamboorules)
![PyPi: Version](https://img.shields.io/pypi/v/bamboorules)

Inspired by Jeremy Wadhams's [JSON-Logic](http://jsonlogic.com/) library.\
Based on [json-logic-py](https://github.com/nadirizr/json-logic-py) by nadirizr.\
Built with [Pandas](https://pandas.pydata.org/).
